@@ -216,9 +216,12 @@ function input(array $field, $value, ?string $function, ?bool $autofocus = false
 	$name = h(bracket_escape($field["field"]));
 	echo "<td class='function'>";
 	if (is_array($value) && !$function) {
-		$value = json_encode($value, 128 | 64 | 256); // 128 - JSON_PRETTY_PRINT, 64 - JSON_UNESCAPED_SLASHES, 256 - JSON_UNESCAPED_UNICODE available since PHP 5.4
 		$function = "json";
 	}
+	$json = ($function == "json" || preg_match('~^jsonb?$~', $field["type"]));
+	if ($json && $value != '' && (JUSH != "pgsql" || $field["type"] != "json")) {
+		$value = json_encode(is_array($value) ? $value : json_decode($value), 128 | 64 | 256); // 128 - JSON_PRETTY_PRINT, 64 - JSON_UNESCAPED_SLASHES, 256 - JSON_UNESCAPED_UNICODE available since PHP 5.4
+	}
 	$reset = (JUSH == "mssql" && $field["auto_increment"]);
 	if ($reset && !$_POST["save"]) {
 		$function = null;
@@ -229,8 +232,7 @@ function input(array $field, $value, ?string $function, ?bool $autofocus = false
 		$field["type"] = "enum";
 		$field["length"] = $enums;
 	}
-	$disabled = stripos($field["default"], "GENERATED ALWAYS AS ") === 0 ? " disabled=''" : "";
-	$attrs = " name='fields[$name]" . ($field["type"] == "enum" || $field["type"] == "set" ? "[]" : "") . "'$disabled" . ($autofocus ? " autofocus" : "");
+	$attrs = " name='fields[$name]" . ($field["type"] == "enum" || $field["type"] == "set" ? "[]" : "") . "'" . ($autofocus ? " autofocus" : "");
 	echo driver()->unconvertFunction($field) . " ";
 	$table = $_GET["edit"] ?: $_GET["select"];
 	if ($field["type"] == "enum") {
@@ -238,7 +240,7 @@ function input(array $field, $value, ?string $function, ?bool $autofocus = false
 	} else {
 		$has_function = (in_array($function, $functions) || isset($functions[$function]));
 		echo (count($functions) > 1
-			? "<select name='function[$name]'$disabled>" . optionlist($functions, $function === null || $has_function ? $function : "") . "</select>"
+			? "<select name='function[$name]'>" . optionlist($functions, $function === null || $has_function ? $function : "") . "</select>"
 				. on_help("event.target.value.replace(/^SQL\$/, '')", 1)
 				. script("qsl('select').onchange = functionChange;", "")
 			: h(reset($functions))
@@ -253,7 +255,7 @@ function input(array $field, $value, ?string $function, ?bool $autofocus = false
 			echo enum_input("checkbox", $attrs, $field, (is_string($value) ? explode(",", $value) : $value));
 		} elseif (is_blob($field) && ini_bool("file_uploads")) {
 			echo "<input type='file' name='fields-$name'>";
-		} elseif ($function == "json" || preg_match('~^jsonb?$~', $field["type"])) {
+		} elseif ($json) {
 			echo "<textarea$attrs cols='50' rows='12' class='jush-js'>" . h($value) . '</textarea>';
 		} elseif (($text = preg_match('~text|lob|memo~i', $field["type"])) || preg_match("~\n~", $value)) {
 			if ($text && JUSH != "sqlite") {
@@ -301,15 +303,15 @@ function input(array $field, $value, ?string $function, ?bool $autofocus = false
 * @return mixed false to leave the original value
 */
 function process_input(array $field) {
-	if (stripos($field["default"], "GENERATED ALWAYS AS ") === 0) {
-		return;
-	}
 	$idf = bracket_escape($field["field"]);
 	$function = idx($_POST["function"], $idf);
 	$value = idx($_POST["fields"], $idf);
+	if ($value === null) {
+		return false;
+	}
 	if ($field["type"] == "enum" || driver()->enumLength($field)) {
-		$value = $value[0];
-		if ($value == "orig") {
+		$value = idx($value, 0);
+		if ($value == "orig" || !$value) {
 			return false;
 		}
 		if ($value == "null") {
@@ -394,6 +396,7 @@ function edit_form(string $table, array $fields, $row, ?bool $update, string $er
 		return;
 	}
 	echo "<form action='' method='post' enctype='multipart/form-data' id='form'>\n";
+	$editable = false;
 	if (!$fields) {
 		echo "<p class='error'>" . lang('You have no privileges to update this table.') . "\n";
 	} else {
@@ -424,30 +427,35 @@ function edit_form(string $table, array $fields, $row, ?bool $update, string $er
 			if (!$_POST["save"] && is_string($value)) {
 				$value = adminer()->editVal($value, $field);
 			}
-			$function = ($_POST["save"]
-				? idx($_POST["function"], $name, "")
-				: ($update && preg_match('~^CURRENT_TIMESTAMP~i', $field["on_update"])
-					? "now"
-					: ($value === false ? null : ($value !== null ? '' : 'NULL'))
-				)
-			);
-			if (!$_POST && !$update && $value == $field["default"] && preg_match('~^[\w.]+\(~', $value)) {
-				$function = "SQL";
-			}
-			if (preg_match("~time~", $field["type"]) && preg_match('~^CURRENT_TIMESTAMP~i', $value)) {
-				$value = "";
-				$function = "now";
-			}
-			if ($field["type"] == "uuid" && $value == "uuid()") {
-				$value = "";
-				$function = "uuid";
-			}
-			if ($autofocus !== false) {
-				$autofocus = ($field["auto_increment"] || $function == "now" || $function == "uuid" ? null : true); // null - don't autofocus this input but check the next one
-			}
-			input($field, $value, $function, $autofocus);
-			if ($autofocus) {
-				$autofocus = false;
+			if (($update && !isset($field["privileges"]["update"])) || $field["generated"]) {
+				echo "<td class='function'><td>" . select_value($value, '', $field, null);
+			} else {
+				$editable = true;
+				$function = ($_POST["save"]
+					? idx($_POST["function"], $name, "")
+					: ($update && preg_match('~^CURRENT_TIMESTAMP~i', $field["on_update"])
+						? "now"
+						: ($value === false ? null : ($value !== null ? '' : 'NULL'))
+					)
+				);
+				if (!$_POST && !$update && $value == $field["default"] && preg_match('~^[\w.]+\(~', $value)) {
+					$function = "SQL";
+				}
+				if (preg_match("~time~", $field["type"]) && preg_match('~^CURRENT_TIMESTAMP~i', $value)) {
+					$value = "";
+					$function = "now";
+				}
+				if ($field["type"] == "uuid" && $value == "uuid()") {
+					$value = "";
+					$function = "uuid";
+				}
+				if ($autofocus !== false) {
+					$autofocus = ($field["auto_increment"] || $function == "now" || $function == "uuid" ? null : true); // null - don't autofocus this input but check the next one
+				}
+				input($field, $value, $function, $autofocus);
+				if ($autofocus) {
+					$autofocus = false;
+				}
 			}
 			echo "\n";
 		}
@@ -463,7 +471,7 @@ function edit_form(string $table, array $fields, $row, ?bool $update, string $er
 		echo "</table>\n";
 	}
 	echo "<p>\n";
-	if ($fields) {
+	if ($editable) {
 		echo "<input type='submit' value='" . lang('Save') . "'>\n";
 		if (!isset($_GET["select"])) {
 			echo "<input type='submit' name='insert' value='" . ($update
