@@ -13,6 +13,7 @@ Lang::$translations = array(
 	'Logged as: %s' => 'Xx: %s',
 	'Logout successful.' => 'Xx.',
 	'Thanks for using Adminer, consider <a href="https://www.adminer.org/en/donation/">donating</a>.' => 'Xx <a href="https://www.adminer.org/en/donation/">xx</a>.',
+	'hostname[:port] or :socket' => 'xx',
 	'Invalid credentials.' => 'Xx.',
 	'There is a space in the input password which might be the cause.' => 'Xx.',
 	'Adminer does not support accessing a database without a password, <a href="https://www.adminer.org/en/password/"%s>more information</a>.' => 'Xx, <a href="https://www.adminer.org/en/password/"%s>xx</a>.',
@@ -77,6 +78,7 @@ Lang::$translations = array(
 	'Webserver file %s' => 'Xx %s',
 	'Run file' => 'Xx',
 	'File does not exist.' => 'Xx.',
+	'Increase %s.' => 'Xx %s.',
 	'File uploads are disabled.' => 'Xx.',
 	'Unable to upload a file.' => 'Xx.',
 	'Maximum allowed file size is %sB.' => 'Xx %sB.',
@@ -196,6 +198,8 @@ Lang::$translations = array(
 	'Partitions' => 'Xx',
 	'Partition name' => 'Xx',
 	'Values' => 'Xx',
+	'Inherits from' => 'Xx',
+	'Inherited by' => 'Xx',
 
 	'View' => 'Xx',
 	'Materialized view' => 'Xx',
@@ -211,6 +215,8 @@ Lang::$translations = array(
 	'Add next' => 'Xx',
 	'Index Type' => 'Xx',
 	'length' => 'xx',
+	'Algorithm' => 'Xx',
+	'Condition' => 'Xx',
 
 	'Foreign keys' => 'Xx',
 	'Foreign key' => 'Xx',
