@@ -13,7 +13,10 @@ class AdminerRowNumbers extends Adminer\Plugin {
 	}
 
 	function backwardKeysPrint($backwardKeys, $row) {
-		static $n = $_GET["page"] * Adminer\adminer()->selectLimitProcess();
+		static $n;
+		if (!$n) {
+			$n = $_GET["page"] * Adminer\adminer()->selectLimitProcess();
+		}
 		$n++;
 		echo "$n.\n";
 	}
